@@ -8,14 +8,14 @@ https://www.aug.ipp.mpg.de/~git/pyaug/sfread.html
 
 """
 __author__  = 'Giovanni Tardini (Tel. 1898)'
-__version__ = '0.1.2'
+__version__ = '0.1.3'
 __date__    = '28.09.2021'
 
 import sys
 
 from .sfread import *
 from .sf2equ import *
-from .libddc import ddcshotnr
+from .libddc import ddcshotnr, previousshot
 from .mapeq import *
 
 # Backward compatibility.
